==> BoutrosLab.plotting.general_7.0.3.tar.gz: BoutrosLab.plotting.general/R/get.defaults.R <==
# The BoutrosLab.plotting.general package is copyright (c) 2012 Ontario Institute for Cancer Research (OICR)
# This package and its accompanying libraries is free software; you can redistribute it and/or modify it under the terms of the GPL
# (either version 1, or at your option, any later version) or the Artistic License 2.0.  Refer to LICENSE for the full license text.
# OICR makes no representations whatsoever as to the SOFTWARE contained herein.  It is experimental in nature and is provided WITHOUT
# WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE OR ANY OTHER WARRANTY, EXPRESS OR IMPLIED. OICR MAKES NO REPRESENTATION
# OR WARRANTY THAT THE USE OF THIS SOFTWARE WILL NOT INFRINGE ANY PATENT OR OTHER PROPRIETARY RIGHT.
# By downloading this SOFTWARE, your Institution hereby indemnifies OICR against any loss, claim, damage or liability, of whatsoever kind or
# nature, which may arise from your Institution's respective use, handling or storage of the SOFTWARE.
# If publications result from research using this SOFTWARE, we ask that the Ontario Institute for Cancer Research be acknowledged and/or
# credit be given to OICR scientists, as scientifically appropriate.

### FUNCTION TO GET OPERATING SYSTEM PROPERTIES ###################################################
get.defaults <- function(property = 'fontfamily', os.type = .Platform$OS.type, add.to.list = NULL, use.legacy.settings = FALSE) {

	# *nix specific settings
	if (os.type == 'unix') {
		if (property == 'fontfamily') {
			if (length(add.to.list) > 0) {
				add.to.list[['fontfamily']] <- if (use.legacy.settings) {'Arial';} else {'ArialMT';}
				}
			else {
				add.to.list <- if (use.legacy.settings) {'Arial';} else {'ArialMT';}
				}
			}
		}

	# windows specific and default settings
	else {
		if (property == 'fontfamily') {
			if (length(add.to.list) > 0) {
				#add.to.list[["fontfamily"]] <- 'Arial'; # PCB -- seems no need to be making these settings anymore, defaults work
				}
			else {
				#add.to.list <- 'Arial'; # PCB -- seems no need to be making these settings anymore, defaults work
				}
			}
		}

	return(add.to.list);
	}

==> BoutrosLab.plotting.general_7.1.2.tar.gz: BoutrosLab.plotting.general/R/get.defaults.R <==
# The BoutrosLab.plotting.general package is copyright (c) 2012 Ontario Institute for Cancer Research (OICR)
# This package and its accompanying libraries is free software; you can redistribute it and/or modify it under the terms of the GPL
# (either version 1, or at your option, any later version) or the Artistic License 2.0.  Refer to LICENSE for the full license text.
# OICR makes no representations whatsoever as to the SOFTWARE contained herein.  It is experimental in nature and is provided WITHOUT
# WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE OR ANY OTHER WARRANTY, EXPRESS OR IMPLIED. OICR MAKES NO REPRESENTATION
# OR WARRANTY THAT THE USE OF THIS SOFTWARE WILL NOT INFRINGE ANY PATENT OR OTHER PROPRIETARY RIGHT.
# By downloading this SOFTWARE, your Institution hereby indemnifies OICR against any loss, claim, damage or liability, of whatsoever kind or
# nature, which may arise from your Institution's respective use, handling or storage of the SOFTWARE.
# If publications result from research using this SOFTWARE, we ask that the Ontario Institute for Cancer Research be acknowledged and/or
# credit be given to OICR scientists, as scientifically appropriate.

### FUNCTION TO GET OPERATING SYSTEM PROPERTIES ###################################################
get.defaults <- function(property = 'fontfamily', os.type = .Platform$OS.type, add.to.list = NULL, use.legacy.settings = FALSE) {

	# *nix specific settings
	if (os.type == 'unix') {
		if (property == 'fontfamily') {
			if (length(add.to.list) > 0) {
				#add.to.list[['fontfamily']] <- if (use.legacy.settings) {'Arial';} else {'ArialMT';}
				}
			else {
				# add.to.list <- if (use.legacy.settings) {'Arial';} else {'ArialMT';}
				}
			}
		}

	# windows specific and default settings
	else {
		if (property == 'fontfamily') {
			if (length(add.to.list) > 0) {
				#add.to.list[["fontfamily"]] <- 'Arial'; # PCB -- seems no need to be making these settings anymore, defaults work
				}
			else {
				#add.to.list <- 'Arial'; # PCB -- seems no need to be making these settings anymore, defaults work
				}
			}
		}

	return(add.to.list);
	}
